@@ -5,6 +5,8 @@ from .custom_code import CustomCode
 from enum import Enum
 from .transformations import Transformation
 from .views import View
+from .functions import Function
+from .procedures import StoredProcedure
 
 
 class ConflictingNameError(ValueError):
@@ -90,7 +92,9 @@ class Entity:
         """
         return self.stage_config[stage]
 
-    def _insert_into_stage_config(self, stage: str, obj: Union[Transformation, View]):
+    def _insert_into_stage_config(
+        self, stage: str, obj: Union[Transformation, View, Function, StoredProcedure]
+    ):
         if stage not in self.stage_config:
             self.stage_config[stage] = {}
         if obj.name in self.stage_config[stage]:
@@ -127,6 +131,16 @@ class Entity:
         """
         self._insert_into_stage_config(stage, view)
 
+    def add_routine(self, stage: str, routine: Union[StoredProcedure, Function]):
+        """Insert a Function or Procedure into the stage_config of the entity.
+
+        :param stage: the name of the stage where to insert the object
+        :type stage: str
+        :param routine: the StoredProcedure or Function object to insert
+        :type routine: StoredProcedure or Function
+        """
+        self._insert_into_stage_config(stage, routine)
+
     def to_dict(self) -> Dict:
         """
         Serialize the entity to a dictionary object.
