@@ -23,8 +23,14 @@ class SchemaUpdateOptions(Enum):
     ALLOW_FIELD_ADDITION = "ALLOW_FIELD_ADDITION"
 
 
+class MultiPartitioningDefinitionError(Exception):
+    """Raised when trying to create a Transformation object with time partitioning & range partitioning."""
+
+    pass
+
+
 class Transformation(QueryBaseWithSchema):
-    """Transformations are the lowest unit inside of a data pipeline. It is a single task implemented as a SQL query."""
+    """Transformations are the lowest unit inside a data pipeline. It is a single task implemented as a SQL query."""
 
     kind = "transformation"
 
@@ -41,6 +47,7 @@ class Transformation(QueryBaseWithSchema):
         persist_backup: Optional[bool] = None,
         write_disposition: Optional[WriteDisposition] = WriteDisposition.APPEND,
         time_partitioning: Optional[dict] = None,
+        range_partitioning: Optional[dict] = None,
         cluster_fields: Optional[List[str]] = None,
         table_expiration: Optional[int] = None,
         partition_expiration: Optional[int] = None,
@@ -53,8 +60,10 @@ class Transformation(QueryBaseWithSchema):
         parsing_dependencies: Optional[List[Dependency]] = None,
         destroy_table: Optional[bool] = False,
         tables: Optional[List[dict]] = None,
+        run_before_keyset: Optional[bool] = False,
         schema: Optional[List[FieldConfig]] = None,
         force_cache_refresh: Optional[bool] = False,
+        keysets_used: Optional[List[str]] = None,
     ):
         """Class representing a transformation.
 
@@ -80,6 +89,8 @@ class Transformation(QueryBaseWithSchema):
         :type write_disposition: WriteDisposition, optional
         :param time_partitioning: An dictionary with the time partition configuration, defaults to None
         :type time_partitioning: dict, optional
+        :param range_partitioning: A dictionary with the range partition configuration , defaults to None (time_partitioning must be None)
+        :type range_partitioning: dict, optional
         :param cluster_fields: An ordered list of the columns you want to cluster on., defaults to None
         :type cluster_fields: List[str], optional
         :param table_expiration: Optional number of day before expiration for the table generated by this transformation
@@ -101,10 +112,14 @@ class Transformation(QueryBaseWithSchema):
         :param tables: If specified, this transformation will generate multiple BigQueryOperator during Airflow generation, one for each table name in this list.
                        The name of the transformation then becomes `{transformation_name}_{table_name}`
         :type tables: List[str], optional
+        :param run_before_keyset: overrides dependencies and runs the custom Operator before the keysets (keysets are Operators run before the Transformations when PII is activated)
+        :type run_before_keyset: bool
         :param schema: List of extra configuration per field of the transformation
         :type schema: List[FieldConfig], optional
         :param force_cache_refresh: whether or not we need to use the cache in the pii service
         :type force_cache_refresh: bool, optional
+        :param keysets_used: List of keysets used in the transformation
+        :type keysets_used: List[str]
         """
         super().__init__(
             name=name,
@@ -120,7 +135,12 @@ class Transformation(QueryBaseWithSchema):
         self.keep_old_columns = keep_old_columns
         self.persist_backup = persist_backup
         self.write_disposition = write_disposition
+        if time_partitioning and range_partitioning:
+            raise MultiPartitioningDefinitionError(
+                "Defining time partitioning & range partitioning is not allowed, you must choose one option between them."
+            )
         self.time_partitioning = time_partitioning
+        self.range_partitioning = range_partitioning
         self.cluster_fields = cluster_fields
         self.table_expiration = table_expiration
         self.partition_expiration = partition_expiration
@@ -131,6 +151,8 @@ class Transformation(QueryBaseWithSchema):
         self.destroy_table = destroy_table
         self.tables = tables
         self.force_cache_refresh = force_cache_refresh
+        self.keysets_used = keysets_used
+        self.run_before_keyset = run_before_keyset
 
     @classmethod
     def from_dict(cls, d: dict):
@@ -155,6 +177,7 @@ class Transformation(QueryBaseWithSchema):
                 d.get("WRITE_DISPOSITION", "WRITE_APPEND")
             ),
             time_partitioning=d.get("TIME_PARTITIONING"),
+            range_partitioning=d.get("RANGE_PARTITIONING"),
             cluster_fields=d.get("CLUSTER_FIELDS"),
             table_expiration=d.get("TABLE_EXPIRATION"),
             partition_expiration=d.get("PARTITION_EXPIRATION"),
@@ -169,8 +192,10 @@ class Transformation(QueryBaseWithSchema):
             ],
             destroy_table=d.get("DESTROY_TABLE", False),
             tables=d.get("TABLES"),
+            run_before_keyset=d.get("RUN_BEFORE_KEYSET"),
             schema=[FieldConfig.from_dict(x) for x in d.get("SCHEMA") or []],
             force_cache_refresh=d.get("FORCE_CACHE_REFRESH", False),
+            keysets_used=d.get("KEYSETS_USED"),
         )
 
     def to_dict(self) -> dict:
@@ -192,6 +217,7 @@ class Transformation(QueryBaseWithSchema):
             "PERSIST_BACKUP": self.persist_backup,
             "WRITE_DISPOSITION": self.write_disposition.value,
             "TIME_PARTITIONING": self.time_partitioning,
+            "RANGE_PARTITIONING": self.range_partitioning,
             "CLUSTER_FIELDS": self.cluster_fields,
             "TABLE_EXPIRATION": self.table_expiration,
             "PARTITION_EXPIRATION": self.partition_expiration,
@@ -205,8 +231,10 @@ class Transformation(QueryBaseWithSchema):
             "DESTROY_TABLE": self.destroy_table,
             "TABLES": self.tables,
             "KIND": self.kind,
+            "RUN_BEFORE_KEYSET": self.run_before_keyset,
             "SCHEMA": [config.to_dict() for config in self.schema],
             "FORCE_CACHE_REFRESH": self.force_cache_refresh,
+            "KEYSETS_USED": self.keysets_used,
         }
 
     def __eq__(self, other):
@@ -223,6 +251,7 @@ class Transformation(QueryBaseWithSchema):
             and self.persist_backup == other.persist_backup
             and self.write_disposition == other.write_disposition
             and self.time_partitioning == other.time_partitioning
+            and self.range_partitioning == other.range_partitioning
             and self.cluster_fields == other.cluster_fields
             and self.table_expiration == other.table_expiration
             and self.partition_expiration == other.partition_expiration
@@ -234,7 +263,9 @@ class Transformation(QueryBaseWithSchema):
             and self.destroy_table == other.destroy_table
             and self.tables == other.tables
             and self.kind == other.kind
+            and self.run_before_keyset == other.run_before_keyset
             and self.schema == other.schema
             and self.force_cache_refresh == other.force_cache_refresh
             and self.schema == other.schema
+            and self.keysets_used == other.keysets_used
         )
